# Django Password

Provides a way to store communal passwords allowing authorised uses access via the admin interface.

Django password encrypts and decrypts passwords using Python's [base64](http://docs.python.org/library/base64.html) library.
